@@ -1,37 +1,41 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
- * The contents of this file are subject to the Mozilla Public License
- * Version 1.1 (the "License"); you may not use this file except in
- * compliance with the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/ 
- * 
+ * ***** BEGIN LICENSE BLOCK *****
+ * Version: MPL 1.1/GPL 2.0/LGPL 2.1
+ *
+ * The contents of this file are subject to the Mozilla Public License Version
+ * 1.1 (the "License"); you may not use this file except in compliance with
+ * the License. You may obtain a copy of the License at
+ * http://www.mozilla.org/MPL/
+ *
  * Software distributed under the License is distributed on an "AS IS" basis,
  * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  * for the specific language governing rights and limitations under the
- * License. 
+ * License.
+ *
+ * The Original Code is The JavaScript Debugger.
  *
- * The Original Code is The JavaScript Debugger
- * 
  * The Initial Developer of the Original Code is
- * Netscape Communications Corporation
- * Portions created by Netscape are
- * Copyright (C) 1998 Netscape Communications Corporation.
- *
- * Alternatively, the contents of this file may be used under the
- * terms of the GNU Public License (the "GPL"), in which case the
- * provisions of the GPL are applicable instead of those above.
- * If you wish to allow use of your version of this file only
- * under the terms of the GPL and not to allow others to use your
- * version of this file under the MPL, indicate your decision by
- * deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL.  If you do not delete
- * the provisions above, a recipient may use your version of this
- * file under either the MPL or the GPL.
+ * Netscape Communications Corporation.
+ * Portions created by the Initial Developer are Copyright (C) 1998
+ * the Initial Developer. All Rights Reserved.
  *
  * Contributor(s):
- *  Robert Ginda, <rginda@netscape.com>, original author
+ *   Robert Ginda, <rginda@netscape.com>, original author
  *
- */
+ * Alternatively, the contents of this file may be used under the terms of
+ * either the GNU General Public License Version 2 or later (the "GPL"), or
+ * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
+ * in which case the provisions of the GPL or the LGPL are applicable instead
+ * of those above. If you wish to allow use of your version of this file only
+ * under the terms of either the GPL or the LGPL, and not to allow others to
+ * use your version of this file under the terms of the MPL, indicate your
+ * decision by deleting the provisions above and replace them with the notice
+ * and other provisions required by the GPL or the LGPL. If you do not delete
+ * the provisions above, a recipient may use your version of this file under
+ * the terms of any one of the MPL, the GPL or the LGPL.
+ *
+ * ***** END LICENSE BLOCK ***** */
 
 const CMD_CONSOLE    = 0x01; // command is available via the console
 const CMD_NEED_STACK = 0x02; // command only works if we're stopped
@@ -104,6 +108,7 @@ function initCommands()
          ["frame",          cmdFrame,             CMD_CONSOLE | CMD_NEED_STACK],
          ["gc",             cmdGC,                                 CMD_CONSOLE],
          ["help",           cmdHelp,                               CMD_CONSOLE],
+         ["inspect",        cmdInspect,                            CMD_CONSOLE],
          ["loadd",          cmdLoadd,                              CMD_CONSOLE],
          ["move-view",      cmdMoveView,                           CMD_CONSOLE],
          ["mozilla-help",   cmdMozillaHelp,                                  0],
@@ -130,6 +135,7 @@ function initCommands()
          ["save-settings",  cmdSaveSettings,                       CMD_CONSOLE],
          ["scan-source",    cmdScanSource,                                   0],
          ["scope",          cmdScope,             CMD_CONSOLE | CMD_NEED_STACK],
+         ["show-profile",   cmdShowProfile,                        CMD_CONSOLE],
          ["this-expr",      cmdThisExpr,                           CMD_CONSOLE],
          ["toggle-float",   cmdToggleFloat,                        CMD_CONSOLE],
          ["toggle-view",    cmdToggleView,                         CMD_CONSOLE],
@@ -147,6 +153,7 @@ function initCommands()
          ["profile-tb",               "profile toggle",                      0],
          ["this",                     "props this",                CMD_CONSOLE],
          ["toggle-chrome",            "chrome-filter toggle",                0],
+         ["toggle-forcescriptload",   "toggle-pref profile.forceScriptLoad", 0],
          ["toggle-ias",               "startup-init toggle",                 0],
          ["toggle-pprint",            "pprint toggle",                       0],
          ["toggle-profile",           "profile toggle",                      0],
@@ -704,11 +711,6 @@ function cmdDoCommand(e)
                       'chrome://communicator/content/pref/pref-navigator.xul', 
                       'navigator');
     }
-    //else if (e.cmdName == "cmd_venkmanPrefs")
-    //{
-    //    window.openDialog('chrome://chatzilla/content/config.xul', '', 
-    //                      'chrome,resizable,dialog=no', window);
-    //}
     else
     {
         doCommand(e.cmdName);
@@ -1207,6 +1209,28 @@ function cmdHook(e)
     /* empty function used for "hook" commands. */
 }
 
+function cmdInspect(e)
+{
+    var key, value;
+    if ("jsdValue" in e)
+    {
+        key = e.propertyName;
+        value = e.jsdValue.getWrappedValue();
+    }
+    else if ("expression" in e)
+    {
+        key = e.expression;
+        value = evalInTargetScope(e.expression, true).getWrappedValue();
+    }
+    if (!value || !isDOMThing(value))
+    {
+        display(getMsg(MSN_ERR_NOT_A_DOM_NODE, key), MT_ERROR);
+        return;
+    }
+    window.openDialog("chrome://inspector/content/", "_blank",
+                      "chrome,all,dialog=no", value);
+}
+
 function cmdLoadd (e)
 {
     var ex;
@@ -1219,7 +1243,7 @@ function cmdLoadd (e)
 
         var cls;
         if ((cls = Components.classes[LOADER_CTRID]))
-            console._loader = cls.createInstance(mozIJSSubScriptLoader);
+            console._loader = cls.getService(mozIJSSubScriptLoader);
     }
     
     var obj = ("scope" in e) ? e.scope : null;
@@ -1678,7 +1702,6 @@ function cmdSaveProfile (e)
     
     var file = fopen (e.targetFile, ">");
 
-    var templateName;
     var ary = file.localFile.path.match(/\.([^.]+)$/);
 
     if (ary)
@@ -1686,52 +1709,9 @@ function cmdSaveProfile (e)
     else
         ext = "txt";
 
-    templateName = templatePfx + ext;
-    var templateFile;
-    if (templateName in console.prefs)
-        templateFile = console.prefs[templateName];
-    else
-        templateFile = console.prefs[templatePfx + "txt"];
-    
-    var reportTemplate = console.profiler.loadTemplate(templateFile);
+    var rv = writeProfile(e, file, ext, onComplete);
 
-    var scriptInstanceList = new Array();
-    
-    var j;
-
-    if (!("urlList" in e) || e.urlList.length == 0)
-    {
-        if ("url" in e && e.url)
-            e.urlList = [e.url];
-        else
-            e.urlList = keys(console.scriptManagers);
-    }
-    
-    e.urlList = e.urlList.sort();
-    
-    for (i = 0; i < e.urlList.length; ++i)
-    {
-        var url = e.urlList[i];
-        if (!ASSERT (url in console.scriptManagers, "url not loaded"))
-            continue;
-        var manager = console.scriptManagers[url];
-        for (j in manager.instances)
-            scriptInstanceList.push (manager.instances[j]);
-    }
-
-    var rangeList;
-    if (("profile.ranges." + ext) in console.prefs)
-        rangeList = console.prefs["profile.ranges." + ext].split(",");
-    else
-        rangeList = console.prefs["profile.ranges.default"].split(",");
-    
-    var profileReport = new ProfileReport (reportTemplate, file, rangeList,
-                                           scriptInstanceList);
-    profileReport.onComplete = onComplete;
-    
-    console.profiler.generateReport (profileReport);
-
-    return file.localFile;
+    return rv.localFile;
 }
 
 function cmdSaveSettings(e)
@@ -1771,6 +1751,82 @@ function cmdScope ()
     return true;
 }
 
+function cmdShowProfile(e)
+{
+    function onComplete(i)
+    {
+        // We need a window since the current browserwindow could be disabled
+        // by us if a script in it is stopped, so we can't do anything there.
+        var w = window.open("about:blank");
+        w.wrappedJSObject.document.open();
+        w.wrappedJSObject.document.write(fileString.str);
+        w.wrappedJSObject.document.close();
+    };
+
+    // In order not to create files, we hack in a small wrapper around a big string:
+    var fileString = {
+        str: "",
+        write: function _write(_str) { this.str += _str; }
+    };
+
+    writeProfile(e, fileString, "html", onComplete);
+}
+
+function writeProfile(e, file, type, onComplete)
+{
+    // Get us a template
+    if (!type)
+        type = "txt";
+
+    var templatePfx = "profile.template.";
+    var templateName = templatePfx + type;
+    var templateFile;
+    if (templateName in console.prefs)
+        templateFile = console.prefs[templateName];
+    else
+        templateFile = console.prefs[templatePfx + "txt"];
+    
+    var reportTemplate = console.profiler.loadTemplate(templateFile);
+
+    // Get a list of scripts we profiled.
+    var scriptInstanceList = new Array();
+    
+    if (!("urlList" in e) || e.urlList.length == 0)
+    {
+        if ("url" in e && e.url)
+            e.urlList = [e.url];
+        else
+            e.urlList = keys(console.scriptManagers);
+    }
+    
+    e.urlList = e.urlList.sort();
+
+    var i, j;
+    for (i = 0; i < e.urlList.length; ++i)
+    {
+        var url = e.urlList[i];
+        if (!ASSERT(url in console.scriptManagers, "url not loaded"))
+            continue;
+        var manager = console.scriptManagers[url];
+        for (j in manager.instances)
+            scriptInstanceList.push(manager.instances[j]);
+    }
+
+    var rangeList;
+    if (("profile.ranges." + type) in console.prefs)
+        rangeList = console.prefs["profile.ranges." + type].split(",");
+    else
+        rangeList = console.prefs["profile.ranges.default"].split(",");
+    
+    var profileReport = new ProfileReport(reportTemplate, file, rangeList,
+                                          scriptInstanceList);
+    profileReport.onComplete = onComplete;
+    
+    console.profiler.generateReport(profileReport);
+
+    return file;
+}
+
 function cmdThisExpr(e)
 {
     if (e.expression == "debugger")
