@@ -24,7 +24,7 @@ function verifyDiskSpace(dirPath, spaceRequired)
 var srDest = 1;
 
 var err = initInstall("JavaScript Debugger", "venkman",
-                      "0.9.85"); 
+                      "0.9.87.2"); 
 
 logComment("initInstall: " + err);
 
